#
# spec file for package libraqm
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           libraqm
Version:        0.7.0
Release:        lp152.1.1
Summary:        Complex Textlayout Library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/HOST-Oman/libraqm
Source:         https://github.com/HOST-Oman/libraqm/releases/download/v%{version}/raqm-%{version}.tar.gz
# PATCH-FIX-OPENSUSE disable some tests for old SuSE Versions
Patch0:         libraqm-test.patch
BuildRequires:  freetype2-devel
BuildRequires:  fribidi-devel
BuildRequires:  gcc
BuildRequires:  gtk-doc
BuildRequires:  harfbuzz-devel

%description
Library that encapsulates the logic for complex
text layout and provides a convenient API.

%package -n %{name}%{sover}
Summary:        Complex Textlayout Library
Group:          System/Libraries

%description -n %{name}%{sover}
Library that encapsulates the logic for complex
text layout and provides a convenient API.

%package doc
Summary:        Libraqm documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package contains documentation files for raqm.

%package devel
Summary:        Complex Textlayout Library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
Library that encapsulates the logic for complex
text layout and provides a convenient API.

%prep
%setup -q -n raqm-%{version}
%if 0%{?suse_version} <= 1510
%patch0 -p1
%endif
%if 0%{?suse_version} >= 1500
sed s:python:%{__python3}:g -i tests/Makefile.in #Fixed in next release on upstream
%endif
%configure --enable-gtk-doc

%build
make %{?_smp_mflags}

%check
export LC_ALL=C.utf8
make %{?_smp_mflags} check

%install
%make_install
rm -f %{buildroot}%{_libdir}/*.{la,a}

%post devel -p /sbin/ldconfig
%postun devel -p /sbin/ldconfig
%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%{_libdir}/libraqm.so.*

%files devel
%{_includedir}/raqm.h
%{_includedir}/raqm-version.h
%{_libdir}/libraqm.so
%{_libdir}/pkgconfig/raqm.pc

%files doc
%license COPYING
%doc AUTHORS NEWS README
%{_datadir}/gtk-doc/html/raqm

%changelog
* Mon May 11 2020 Joop Boonen <joop.boonen@opensuse.org>
- Build version 0.7.0
  * New functions:
    raqm_version()
    raqm_version_string()
    raqm_version_atleast()
  * New macros:
    RAQM_VERSION_MAJOR
    RAQM_VERSION_MICRO
    RAQM_VERSION_MINOR
    RAQM_VERSION_STRING
    RAQM_VERSION_ATLEAST()
- Since version 0.6.0
  * Fix TTB direction regression from the previous release (#81)
  * Add raqm_set_invisible_glyph() (#92)
  * Correctly detect script of Common and Inherite characters at start of text (#95)
  * Undef HAVE_CONFIG_H workaround, for older versions of Fribidi (#101)
  * Drop test suite dependency on GLib
  * Port test runner to Python instead of shell script
- Renamed patch libraqm-GB8a.patch to libraqm-test.patch
* Tue Feb 12 2019 Jan Engelhardt <jengelh@inai.de>
- Rename %%soname to %%sover to better reflect its use.
- Rename libraqm-docs to libraqm-doc to better match the
  rest of openSUSE packages.
- Fix RPM groups.
- Avoid double-shipping doc files.
* Thu Dec 27 2018 Joop Boonen <joop.boonen@opensuse.org>
- Build the opensuse version of this package
* Sun Nov 18 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>
- Use C.UTF-8 locale
  See https://fedoraproject.org/wiki/Changes/Remove_glibc-langpacks-all_from_buildroot
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild
* Wed Mar 14 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com>
- Update to latest version
* Wed Feb  7 2018 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild
* Thu Aug  3 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild
* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild
* Sun May  1 2016 Mosaab Alzoubi <moceap@hotmail.com>
- Updated to 0.1.1
* Mon Apr 25 2016 Mosaab Alzoubi <moceap@hotmail.com>
- Use lib prefix in %%%%name
- Depends on same version -devel
* Sun Apr 24 2016 Mosaab Alzoubi <moceap@hotmail.com>
- General revision
* Sat Apr 23 2016 Mosaab Alzoubi <moceap@hotmail.com>
- Initial build
